==> kimap2-0.2.0.tar.xz: kimap2-0.2.0/src/subscribejob.cpp <==
/*
    Copyright (c) 2009 Andras Mantia <amantia@kde.org>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
*/

#include "subscribejob.h"

#include "job_p.h"
#include "message_p.h"
#include "session_p.h"
#include "rfccodecs.h"

namespace KIMAP2
{
class SubscribeJobPrivate : public JobPrivate
{
public:
    SubscribeJobPrivate(Session *session, const QString &name) : JobPrivate(session, name) { }
    ~SubscribeJobPrivate() { }

    QString mailBox;
};
}

using namespace KIMAP2;

SubscribeJob::SubscribeJob(Session *session)
    : Job(*new SubscribeJobPrivate(session, "Subscribe"))
{
}

SubscribeJob::~SubscribeJob()
{
}

void SubscribeJob::doStart()
{
    Q_D(SubscribeJob);
    d->tags << d->sessionInternal()->sendCommand("SUBSCRIBE", '\"' + KIMAP2::encodeImapFolderName(d->mailBox.toUtf8()) + '\"');
}

void SubscribeJob::setMailBox(const QString &mailBox)
{
    Q_D(SubscribeJob);
    d->mailBox = mailBox;
}

QString SubscribeJob::mailBox() const
{
    Q_D(const SubscribeJob);
    return d->mailBox;
}

==> kimap2-0.3.0.tar.xz: kimap2-0.3.0/src/subscribejob.cpp <==
/*
    Copyright (c) 2009 Andras Mantia <amantia@kde.org>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
*/

#include "subscribejob.h"

#include "job_p.h"
#include "message_p.h"
#include "session_p.h"
#include "rfccodecs.h"

namespace KIMAP2
{
class SubscribeJobPrivate : public JobPrivate
{
public:
    SubscribeJobPrivate(Session *session, const QString &name) : JobPrivate(session, name) { }
    ~SubscribeJobPrivate() { }

    QString mailBox;
};
}

using namespace KIMAP2;

SubscribeJob::SubscribeJob(Session *session)
    : Job(*new SubscribeJobPrivate(session, "Subscribe"))
{
}

SubscribeJob::~SubscribeJob()
{
}

void SubscribeJob::doStart()
{
    Q_D(SubscribeJob);
    d->sendCommand("SUBSCRIBE", '\"' + KIMAP2::encodeImapFolderName(d->mailBox.toUtf8()) + '\"');
}

void SubscribeJob::setMailBox(const QString &mailBox)
{
    Q_D(SubscribeJob);
    d->mailBox = mailBox;
}

QString SubscribeJob::mailBox() const
{
    Q_D(const SubscribeJob);
    return d->mailBox;
}
